@@ -6,7 +6,7 @@ from django.utils.module_loading import import_string
 
 from django_comments.models import CommentFlag
 from django_comments.views.moderation import perform_flag
-from rest_framework import generics, mixins, permissions, status
+from rest_framework import generics, mixins, permissions, status, renderers
 from rest_framework.decorators import api_view
 from rest_framework.response import Response
 from rest_framework.schemas.openapi import AutoSchema
@@ -24,7 +24,21 @@ from django_comments_xtd.utils import get_current_site_id
 XtdComment = get_model()
 
 
-class CommentCreate(generics.CreateAPIView):
+class DefaultsMixin():
+    @property
+    def renderer_classes(self):
+        if self.kwargs.get('override_drf_defaults', False):
+            return (renderers.JSONRenderer, renderers.BrowsableAPIRenderer)
+        return super().renderer_classes
+
+    @property
+    def pagination_class(self):
+        if self.kwargs.get('override_drf_defaults', False):
+            return None
+        return super().pagination_class
+
+
+class CommentCreate(DefaultsMixin, generics.CreateAPIView):
     """Create a comment."""
     serializer_class = serializers.WriteCommentSerializer
 
@@ -50,9 +64,10 @@ class CommentCreate(generics.CreateAPIView):
         self.resp_dict = serializer.save()
 
 
-class CommentList(generics.ListAPIView):
+class CommentList(DefaultsMixin, generics.ListAPIView):
     """List all comments for a given ContentType and object ID."""
     serializer_class = serializers.ReadCommentSerializer
+    permission_classes = (permissions.AllowAny,)
 
     def get_queryset(self, **kwargs):
         content_type_arg = self.kwargs.get('content_type', None)
@@ -80,9 +95,10 @@ class CommentList(generics.ListAPIView):
         return qs
 
 
-class CommentCount(generics.GenericAPIView):
+class CommentCount(DefaultsMixin, generics.GenericAPIView):
     """Get number of comments posted to a given ContentType and object ID."""
     serializer_class = serializers.ReadCommentSerializer
+    permission_classes = (permissions.AllowAny,)
 
     def get_queryset(self):
         content_type_arg = self.kwargs.get('content_type', None)
@@ -98,7 +114,8 @@ class CommentCount(generics.GenericAPIView):
         return Response({'count': self.get_queryset().count()})
 
 
-class ToggleFeedbackFlag(generics.CreateAPIView, mixins.DestroyModelMixin):
+class ToggleFeedbackFlag(
+        DefaultsMixin, generics.CreateAPIView, mixins.DestroyModelMixin):
     """Create and delete like/dislike flags."""
 
     serializer_class = serializers.FlagSerializer
@@ -119,7 +136,7 @@ class ToggleFeedbackFlag(generics.CreateAPIView, mixins.DestroyModelMixin):
         self.created = f(self.request, serializer.validated_data['comment'])
 
 
-class CreateReportFlag(generics.CreateAPIView):
+class CreateReportFlag(DefaultsMixin, generics.CreateAPIView):
     """Create 'removal suggestion' flags."""
 
     serializer_class = serializers.FlagSerializer
@@ -135,9 +152,8 @@ class CreateReportFlag(generics.CreateAPIView):
 
 
 @api_view(["POST"])
-def preview_user_avatar(request):
+def preview_user_avatar(request, *args, **kwargs):
     """Fetch the image associated with the user previewing the comment."""
-    print("I am here")
     temp_comment = TmpXtdComment({
         'user': None,
         'user_email': request.data['email']
