@@ -1,5 +1,6 @@
 from django.apps import AppConfig
 
+
 class CommentsXtdTestsConfig(AppConfig):
     name = 'django_comments_xtd.tests'
-    verbose_name = 'Comments Xtd Tests'
+    verbose_name = 'django-comments-xtd tests'
